@@ -107,30 +107,32 @@ class SQLTableDataSet(AbstractDataSet[pd.DataFrame, pd.DataFrame]):
     the data with no index. This is designed to make load and save methods
     symmetric.
 
-    Example adding a catalog entry with
+    Example usage for the
     `YAML API <https://kedro.readthedocs.io/en/stable/data/\
-        data_catalog.html#use-the-data-catalog-with-the-yaml-api>`_:
+    data_catalog.html#use-the-data-catalog-with-the-yaml-api>`_:
 
     .. code-block:: yaml
 
-        >>> shuttles_table_dataset:
-        >>>   type: pandas.SQLTableDataSet
-        >>>   credentials: db_credentials
-        >>>   table_name: shuttles
-        >>>   load_args:
-        >>>     schema: dwschema
-        >>>   save_args:
-        >>>     schema: dwschema
-        >>>     if_exists: replace
+        shuttles_table_dataset:
+          type: pandas.SQLTableDataSet
+          credentials: db_credentials
+          table_name: shuttles
+          load_args:
+            schema: dwschema
+          save_args:
+            schema: dwschema
+            if_exists: replace
 
     Sample database credentials entry in ``credentials.yml``:
 
     .. code-block:: yaml
 
-            >>> db_credentials:
-            >>>     con: postgresql://scott:tiger@localhost/test
+        db_credentials:
+          con: postgresql://scott:tiger@localhost/test
 
-    Example using Python API:
+    Example usage for the
+    `Python API <https://kedro.readthedocs.io/en/stable/data/\
+    data_catalog.html#use-the-data-catalog-with-the-code-api>`_:
     ::
 
         >>> from kedro.extras.datasets.pandas import SQLTableDataSet
@@ -241,11 +243,11 @@ class SQLTableDataSet(AbstractDataSet[pd.DataFrame, pd.DataFrame]):
         save_args = copy.deepcopy(self._save_args)
         del load_args["table_name"]
         del save_args["name"]
-        return dict(
-            table_name=self._load_args["table_name"],
-            load_args=load_args,
-            save_args=save_args,
-        )
+        return {
+            "table_name": self._load_args["table_name"],
+            "load_args": load_args,
+            "save_args": save_args,
+        }
 
     def _load(self) -> pd.DataFrame:
         engine = self.engines[self._connection_str]  # type:ignore
@@ -276,38 +278,40 @@ class SQLQueryDataSet(AbstractDataSet[None, pd.DataFrame]):
     To save data to a SQL server use ``SQLTableDataSet``.
 
 
-    Example adding a catalog entry with
+    Example usage for the
     `YAML API <https://kedro.readthedocs.io/en/stable/data/\
-        data_catalog.html#use-the-data-catalog-with-the-yaml-api>`_:
+    data_catalog.html#use-the-data-catalog-with-the-yaml-api>`_:
 
     .. code-block:: yaml
 
-        >>> shuttle_id_dataset:
-        >>>   type: pandas.SQLQueryDataSet
-        >>>   sql: "select shuttle, shuttle_id from spaceflights.shuttles;"
-        >>>   credentials: db_credentials
+        shuttle_id_dataset:
+          type: pandas.SQLQueryDataSet
+          sql: "select shuttle, shuttle_id from spaceflights.shuttles;"
+          credentials: db_credentials
 
-    Advanced example using the `stream_results` and `chunksize` option to reduce memory usage
+    Advanced example using the ``stream_results`` and ``chunksize`` options to reduce memory usage:
 
     .. code-block:: yaml
 
-        >>> shuttle_id_dataset:
-        >>>   type: pandas.SQLQueryDataSet
-        >>>   sql: "select shuttle, shuttle_id from spaceflights.shuttles;"
-        >>>   credentials: db_credentials
-        >>>   execution_options:
-        >>>     stream_results: true
-        >>>   load_args:
-        >>>     chunksize: 1000
+        shuttle_id_dataset:
+          type: pandas.SQLQueryDataSet
+          sql: "select shuttle, shuttle_id from spaceflights.shuttles;"
+          credentials: db_credentials
+          execution_options:
+            stream_results: true
+          load_args:
+            chunksize: 1000
 
     Sample database credentials entry in ``credentials.yml``:
 
     .. code-block:: yaml
 
-            >>> db_credentials:
-            >>>     con: postgresql://scott:tiger@localhost/test
+        db_credentials:
+          con: postgresql://scott:tiger@localhost/test
 
-    Example using Python API:
+    Example usage for the
+    `Python API <https://kedro.readthedocs.io/en/stable/data/\
+    data_catalog.html#use-the-data-catalog-with-the-code-api>`_:
     ::
 
         >>> from kedro.extras.datasets.pandas import SQLQueryDataSet
@@ -323,7 +327,6 @@ class SQLQueryDataSet(AbstractDataSet[None, pd.DataFrame]):
         >>>                            credentials=credentials)
         >>>
         >>> sql_data = data_set.load()
-        >>>
 
     """
 
@@ -437,12 +440,12 @@ class SQLQueryDataSet(AbstractDataSet[None, pd.DataFrame]):
 
     def _describe(self) -> Dict[str, Any]:
         load_args = copy.deepcopy(self._load_args)
-        return dict(
-            sql=str(load_args.pop("sql", None)),
-            filepath=str(self._filepath),
-            load_args=str(load_args),
-            execution_options=str(self._execution_options),
-        )
+        return {
+            "sql": str(load_args.pop("sql", None)),
+            "filepath": str(self._filepath),
+            "load_args": str(load_args),
+            "execution_options": str(self._execution_options),
+        }
 
     def _load(self) -> pd.DataFrame:
         load_args = copy.deepcopy(self._load_args)
