@@ -7,9 +7,10 @@ import subprocess
 import traceback
 from copy import deepcopy
 from pathlib import Path
-from typing import Any, Dict, Iterable, Union
+from typing import Any, Dict, Iterable, Optional, Union
 
 import click
+from omegaconf import OmegaConf, omegaconf
 
 from kedro import __version__ as kedro_version
 from kedro.config import ConfigLoader, MissingConfigException
@@ -69,6 +70,7 @@ class KedroSessionError(Exception):
     pass
 
 
+# pylint: disable=too-many-instance-attributes
 class KedroSession:
     """``KedroSession`` is the object that is responsible for managing the lifecycle
     of a Kedro run. Use `KedroSession.create()` as
@@ -93,12 +95,14 @@ class KedroSession:
 
     """
 
+    # pylint: disable=too-many-arguments
     def __init__(
         self,
         session_id: str,
         package_name: str = None,
         project_path: Union[Path, str] = None,
         save_on_close: bool = False,
+        conf_source: Optional[str] = None,
     ):
         self._project_path = Path(project_path or Path.cwd()).resolve()
         self.session_id = session_id
@@ -112,6 +116,10 @@ class KedroSession:
         _register_hooks_setuptools(hook_manager, settings.DISABLE_HOOKS_FOR_PLUGINS)
         self._hook_manager = hook_manager
 
+        self._conf_source = conf_source or str(
+            self._project_path / settings.CONF_SOURCE
+        )
+
     @classmethod
     def create(  # pylint: disable=too-many-arguments
         cls,
@@ -120,6 +128,7 @@ class KedroSession:
         save_on_close: bool = True,
         env: str = None,
         extra_params: Dict[str, Any] = None,
+        conf_source: Optional[str] = None,
     ) -> "KedroSession":
         """Create a new instance of ``KedroSession`` with the session data.
 
@@ -129,6 +138,7 @@ class KedroSession:
             project_path: Path to the project root directory. Default is
                 current working directory Path.cwd().
             save_on_close: Whether or not to save the session when it's closed.
+            conf_source: Path to a directory containing configuration
             env: Environment for the KedroContext.
             extra_params: Optional dictionary containing extra project parameters
                 for underlying KedroContext. If specified, will update (and therefore
@@ -145,6 +155,7 @@ class KedroSession:
             project_path=project_path,
             session_id=generate_timestamp(),
             save_on_close=save_on_close,
+            conf_source=conf_source,
         )
 
         # have to explicitly type session_data otherwise mypy will complain
@@ -182,6 +193,8 @@ class KedroSession:
 
     def _get_logging_config(self) -> Dict[str, Any]:
         logging_config = self._get_config_loader()["logging"]
+        if isinstance(logging_config, omegaconf.DictConfig):
+            logging_config = OmegaConf.to_container(logging_config)
         # turn relative paths in logging config into absolute path
         # before initialising loggers
         logging_config = _convert_paths_to_absolute_posix(
@@ -268,7 +281,7 @@ class KedroSession:
 
         config_loader_class = settings.CONFIG_LOADER_CLASS
         return config_loader_class(
-            conf_source=str(self._project_path / settings.CONF_SOURCE),
+            conf_source=self._conf_source,
             env=env,
             runtime_params=extra_params,
             **settings.CONFIG_LOADER_ARGS,
@@ -300,6 +313,7 @@ class KedroSession:
         from_inputs: Iterable[str] = None,
         to_outputs: Iterable[str] = None,
         load_versions: Dict[str, str] = None,
+        namespace: str = None,
     ) -> Dict[str, Any]:
         """Runs the pipeline with a specified runner.
 
@@ -323,6 +337,7 @@ class KedroSession:
                 used as an end point of the new ``Pipeline``.
             load_versions: An optional flag to specify a particular dataset
                 version timestamp to load.
+            namespace: The namespace of the nodes that is being run.
         Raises:
             ValueError: If the named or `__default__` pipeline is not
                 defined by `register_pipelines`.
@@ -369,6 +384,7 @@ class KedroSession:
             node_names=node_names,
             from_inputs=from_inputs,
             to_outputs=to_outputs,
+            node_namespace=namespace,
         )
 
         record_data = {
@@ -385,6 +401,7 @@ class KedroSession:
             "load_versions": load_versions,
             "extra_params": extra_params,
             "pipeline_name": pipeline_name,
+            "namespace": namespace,
             "runner": getattr(runner, "__name__", str(runner)),
         }
 
